@@ -1,6 +1,6 @@
 /*
- * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
- *                                                            1998, 2005
+ * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
+ *                                                            1998, 2006
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -27,40 +27,16 @@
 
 void ccharset()
 {
-
-   if(strcmp(CharSet,"Latin2") == 0)
-      strcpy(CharSet,"ISO-8859-2");
-
-   if(strcmp(CharSet,"Latin3") == 0)
-      strcpy(CharSet,"ISO-8859-3");
-
-   if(strcmp(CharSet,"Latin4") == 0)
-      strcpy(CharSet,"ISO-8859-4");
-
-   if(strcmp(CharSet,"Cyrillic") == 0)
-      strcpy(CharSet,"ISO-8859-5");
-
-   if(strcmp(CharSet,"Arabic") == 0)
-      strcpy(CharSet,"ISO-8859-6");
-
-   if(strcmp(CharSet,"Greek") == 0)
-      strcpy(CharSet,"ISO-8859-7");
-
-   if(strcmp(CharSet,"Hebrew") == 0)
-      strcpy(CharSet,"ISO-8859-8");
-
-   if(strcmp(CharSet,"Latin5") == 0)
-      strcpy(CharSet,"ISO-8859-9");
-
-   if(strcmp(CharSet,"Latin6") == 0)
-      strcpy(CharSet,"ISO-8859-10");
-
-   if(strcmp(CharSet,"Windows-1251") == 0)
-      strcpy(CharSet,"Windows-1251");
-
-   if(strcmp(CharSet,"Koi8-r") == 0)
-      strcpy(CharSet,"KOI8-R");
-
+   if(strcmp(CharSet,"Latin2") == 0) strcpy(CharSet,"ISO-8859-2");
+   else if(strcmp(CharSet,"Latin3") == 0) strcpy(CharSet,"ISO-8859-3");
+   else if(strcmp(CharSet,"Latin4") == 0) strcpy(CharSet,"ISO-8859-4");
+   else if(strcmp(CharSet,"Cyrillic") == 0) strcpy(CharSet,"ISO-8859-5");
+   else if(strcmp(CharSet,"Arabic") == 0) strcpy(CharSet,"ISO-8859-6");
+   else if(strcmp(CharSet,"Greek") == 0) strcpy(CharSet,"ISO-8859-7");
+   else if(strcmp(CharSet,"Hebrew") == 0) strcpy(CharSet,"ISO-8859-8");
+   else if(strcmp(CharSet,"Latin5") == 0) strcpy(CharSet,"ISO-8859-9");
+   else if(strcmp(CharSet,"Latin6") == 0) strcpy(CharSet,"ISO-8859-10");
+   else if(strcmp(CharSet,"Windows-1251") == 0) strcpy(CharSet,"Windows-1251");
+   else if(strcmp(CharSet,"Koi8-r") == 0) strcpy(CharSet,"KOI8-R");
    return;
-
 }
