@@ -1,6 +1,6 @@
 /*
- * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
- *                                                            1998, 2005
+ * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
+ *                                                            1998, 2006
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -34,7 +34,7 @@ int geramail(const char *dirname, int debug, const char *outdir, int userip, cha
    float perc=0.00;
    float perc2=0.00;
    int posicao=0;
-   char olduser[MAXLEN], csort[MAXLEN], periodo[MAXLEN], arqper[MAXLEN];
+   char olduser[MAXLEN], csort[MAXLEN], period[MAXLEN], arqper[MAXLEN];
    char wger[MAXLEN], top1[MAXLEN], top2[MAXLEN], top3[MAXLEN], user[MAXLEN], nacc[20], nbytes[20], url[1024], preg[MAXLEN], tusr[MAXLEN];
    char ip[MAXLEN], hora[9], data[11], elap[15], user2[MAXLEN], wperc[8], wperc2[8];
    char strip1[MAXLEN], strip2[MAXLEN], strip3[MAXLEN], strip4[MAXLEN], strip5[MAXLEN], strip6[MAXLEN], strip7[MAXLEN];
@@ -48,7 +48,7 @@ int geramail(const char *dirname, int debug, const char *outdir, int userip, cha
    strcpy(top2,dirname);
    strcpy(top3,dirname);
    strcpy(tusr,dirname);
-   strcat(wger,"/geral");
+   strcat(wger,"/general");
    strcat(top1,"/top");
    strcat(top2,"/top.tmp");
    strcat(top3,"/report");
@@ -172,18 +172,18 @@ int geramail(const char *dirname, int debug, const char *outdir, int userip, cha
    }
 
  /*
- * Obtem o periodo
+ * Obtem o period
  */
 
    strcpy(arqper,dirname);
-   strcat(arqper,"/periodo");
+   strcat(arqper,"/period");
 
    if ((fp_in = fopen(arqper, "r")) == 0){
       fprintf(stderr, "SARG: (email) %s: %s\n",text[45],arqper);
       exit(1);
    }
 
-   fgets(periodo,sizeof(periodo),fp_in);
+   fgets(period,sizeof(period),fp_in);
    fclose(fp_in);
 
    sprintf(strip1,"%s",text[88]);
@@ -198,7 +198,7 @@ int geramail(const char *dirname, int debug, const char *outdir, int userip, cha
 
    sprintf(strip1,"%s",text[89]);
    strip_latin(strip1);
-   sprintf(preg,"%s %s\n\n",strip1,periodo);
+   sprintf(preg,"%s %s\n\n",strip1,period);
    fputs(preg,fp_top3);
 
    sprintf(strip1,"%s",text[100]);
