@@ -1,6 +1,6 @@
 /*
- * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
- *                                                            1998, 2005
+ * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
+ *                                                            1998, 2006
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -30,43 +30,7 @@ extern numlist hours, weekdays;
 char wbuf[MAXLEN];
 char Msg[255];
 
-void getconf()
-{
-
-   FILE *fp_in;
-   char buf[MAXLEN];
-
-   if(debug) {
-      sprintf(Msg,"Loading configuration from: %s",ConfigFile);
-      debuga(Msg);
-   }
-
-   if ((fp_in = fopen(ConfigFile, "r")) == NULL) {
-      fprintf(stderr, "SARG: (getconf) Cannot open file: %s\n",ConfigFile);
-      exit(1);
-   }
-
-   while (fgets(buf, MAXLEN, fp_in) != NULL) {
-      if(strstr(buf,"\n") != 0)
-         buf[strlen(buf)-1]='\n';
-
-      if(debugm)
-         printf("SYSCONFDIR %s",buf);
-
-      if(strncmp(buf,"#",1) == 0)
-         continue;
-
-      parmtest(buf);
-
-   }
-
-   fclose(fp_in);
-   language_load(language);
-   return;
-}
-
-
-int parmtest(char *buf)
+void parmtest(char *buf)
 {
 
       if(strstr(buf,"background_color") != 0) {
@@ -810,6 +774,39 @@ int parmtest(char *buf)
          nocost=my_atoll(buf);
          return;
       }
-    
-      return;
+}
+
+void getconf()
+{
+
+   FILE *fp_in;
+   char buf[MAXLEN];
+
+   if(debug) {
+      sprintf(Msg,"Loading configuration from: %s",ConfigFile);
+      debuga(Msg);
+   }
+
+   if ((fp_in = fopen(ConfigFile, "r")) == NULL) {
+      fprintf(stderr, "SARG: (getconf) Cannot open file: %s\n",ConfigFile);
+      exit(1);
+   }
+
+   while (fgets(buf, MAXLEN, fp_in) != NULL) {
+      if(strstr(buf,"\n") != 0)
+         buf[strlen(buf)-1]='\n';
+
+      if(debugm)
+         printf("SYSCONFDIR %s",buf);
+
+      if(strncmp(buf,"#",1) == 0)
+         continue;
+
+      parmtest(buf);
+
+   }
+
+   fclose(fp_in);
+   language_load(language);
+   return;
 }
