@@ -1,6 +1,6 @@
 /*
- * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
- *                                                            1998, 2005
+ * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
+ *                                                            1998, 2006
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -39,6 +39,7 @@ int x1;
 char *font1 = SYSCONFDIR"/fonts/FreeSans.ttf";
 char s[15];
 
+#ifdef HAVE_GD
 #ifdef HAVE_ICONV_H
 #include <iconv.h>
 #define SARGgdImageStringFT I18NgdImageStringFT
@@ -59,7 +60,7 @@ BGD_DECLARE(char *) I18NgdImageStringFT (gdImage * im, int *brect, int fg, char
  sstr = (char *) sstring;
 
  localtoutf = iconv_open ("UTF-8", CharSet);
- iconv (localtoutf, &str, &slen, &sstr, &sslen);
+ iconv (localtoutf, (ICONV_CONST char **)&str, &slen, &sstr, &sslen); 
  iconv_close (localtoutf);
 
  retval = gdImageStringFTEx (im, brect, fg, fontlist, ptsize, angle, x, y, sstring, gdFTEX_Unicode);
@@ -70,6 +71,7 @@ BGD_DECLARE(char *) I18NgdImageStringFT (gdImage * im, int *brect, int fg, char
 #else
 #define SARGgdImageStringFT gdImageStringFT
 #endif
+#endif
 
 void *bar(long long int *n)
 {     
@@ -77,7 +79,6 @@ void *bar(long long int *n)
    gdPoint points[4];
    int brect[8];
    int val=0, x;
-   float f=0;
    long long int lim, num;
    char v[15];
 
@@ -232,7 +233,7 @@ void *bar(long long int *n)
 void greport_day(char *user, int *iprel, int *ipuser)
 {
    FILE *fp_in, *pngout;
-   int x, y, z;
+   int x, y;
    int brect[8];
    char wdirname[MAXLEN];
    char graph[MAXLEN];
@@ -329,7 +330,7 @@ void greport_day(char *user, int *iprel, int *ipuser)
    SARGgdImageStringFT(im,&brect[0],darkblue,font1,7,0.0,620,470,ftime);
    if(strcmp(ShowSargInfo,"yes") == 0) SARGgdImageStringFT(im,&brect[0],darkblue,font1,10,0.0,257,15,"SARG, ");
    SARGgdImageStringFT(im,&brect[0],darkblue,font1,10,0.0,300,15,Title);
-   sprintf(warea,"%s: %s",text[89],periodo);
+   sprintf(warea,"%s: %s",text[89],period);
    SARGgdImageStringFT(im,&brect[0],darkblue,font1,9,0.0,300,27,warea);
    sprintf(warea,"%s: %s",text[90],name);
    SARGgdImageStringFT(im,&brect[0],darkblue,font1,9,0.0,300,38,warea);
