@@ -1,6 +1,6 @@
 /*
- * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
- *                                                            1998, 2005
+ * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
+ *                                                            1998, 2006
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -102,8 +102,7 @@ int main(argc,argv)
    int  common_log=0;
    int  squid_log=0;
    int  ch;
-   int  d;
-   int  x, l, i;
+   int  x, l;
    int  errflg=0;
    int  puser=0;
    int  fhost=0;
@@ -140,7 +139,6 @@ int main(argc,argv)
    code[0]='\0';
    LastLog[0]='\0';
    UserIp[0]='\0';
-   MaxElapsed[0]='\0';
    ReportType[0]='\0';
    UserTabFile[0]='\0';
    BlockIt[0]='\0';
@@ -163,7 +161,7 @@ int main(argc,argv)
    strcpy(LogoTextColor,"#006699");
    strcpy(FontSize,"9px");
    strcpy(TempDir,"/tmp");
-   strcpy(OutputDir,"/usr/local/etc/httpd/htdocs/squid-reports");
+   strcpy(OutputDir,"/var/www/html/squid-reports");
    strcpy(Ip2Name,"no");
    strcpy(DateFormat,"u");
    strcpy(OverwriteReport,"no");
@@ -218,6 +216,7 @@ int main(argc,argv)
    strcpy(SquidguardIgnoreDate,"off");
    strcpy(DansguardianIgnoreDate,"off");
    strcpy(DataFileUrl,"ip");
+   strcpy(MaxElapsed,"28800000");
 
    dia[0]='\0';
    mes[0]='\0';
@@ -405,18 +404,14 @@ int main(argc,argv)
       exit(2);
    }
 
-   if(debug)
-      debuga("Init");
+   if(debug) debuga("Init");
 
-   if(ConfigFile[0] == '\0')
-      sprintf(ConfigFile,"%s/sarg.conf",SYSCONFDIR);
-    else {
-      if(access(ConfigFile, R_OK) != 0) {
-         sprintf(msg,"Cannot open config file: %s - %s",ConfigFile,strerror(errno));
-         debuga(msg);
-         exit(1);
-      }
-   }
+   if(ConfigFile[0] == '\0') sprintf(ConfigFile,"%s/sarg.conf",SYSCONFDIR);
+    else if(access(ConfigFile, R_OK) != 0) {
+            sprintf(msg,"Cannot open config file: %s - %s",ConfigFile,strerror(errno));
+            debuga(msg);
+            exit(1);
+         }
     
    if(access(ConfigFile, R_OK) == 0)
       getconf(debugm, ConfigFile, AccessLog, debug, BgColor, TxColor, TxBgColor, TiColor, LogoImage, LogoText, LogoTextColor, Width, Height, Title, BgImage, FontFace, HeaderColor, HeaderBgColor, FontSize, PasswdFile, TempDir, OutputDir, OutputEmail, Ip2Name, TopuserSortField, UserSortField, TopuserSortOrder, UserSortOrder, UserAgentLog, ExcludeHosts, DateFormat, ExcludeUsers, PerUserLimitFile, PerUserLimit, UserIp, MaxElapsed);
@@ -534,50 +529,35 @@ int main(argc,argv)
       if(strstr(excludeuser,"indexonly") != 0)
          indexonly++;
    }
-   if(strcmp(ExcludeUsers,"indexonly") == 0)
-      indexonly++;
-   if(strcmp(Index,"only") == 0)
-      indexonly++;
+   if(strcmp(ExcludeUsers,"indexonly") == 0) indexonly++;
+   if(strcmp(Index,"only") == 0) indexonly++;
 
-   if(dns)
-      strcpy(Ip2Name,"yes");
+   if(dns) strcpy(Ip2Name,"yes");
 
-   if(strcmp(UserIp,"yes") == 0)
-      userip++;
+   if(strcmp(UserIp,"yes") == 0) userip++;
 
-   if(strlen(MaxElapsed)>1)
-      max_elapsed=atol(MaxElapsed);
+   if(strlen(MaxElapsed)>1) max_elapsed=atol(MaxElapsed);
 
-   if(strlen(outdir)<1)
-      strcpy(outdir,OutputDir);
+   if(strlen(outdir)<1) strcpy(outdir,OutputDir);
    strcat(outdir,"/");
 
 
-   if(arq[0] == '\0')
-      strcpy(arq,AccessLog);
+   if(arq[0] == '\0') strcpy(arq,AccessLog);
 
-   if(uagent[0] == '\0')
-      strcpy(uagent,UserAgentLog);
+   if(uagent[0] == '\0') strcpy(uagent,UserAgentLog);
 
-   if(tmp[0] == '\0')
-     strcpy(tmp,TempDir);
-    else
-     strcpy(TempDir,tmp);
+   if(tmp[0] == '\0') strcpy(tmp,TempDir);
+   else strcpy(TempDir,tmp);
 
-   if(df[0] == '\0')
-      strcpy(df,DateFormat);
-    else
-      strcpy(DateFormat,df);
+   if(df[0] == '\0') strcpy(df,DateFormat);
+   else strcpy(DateFormat,df);
 
    if(df[0] == '\0') {
       strcpy(df,"u");
       strcpy(DateFormat,"u");
    }
 
-   if(strlen(email)<1){
-      if(strlen(OutputEmail)>0)
-         strcpy(email,OutputEmail);
-   }
+   if(strlen(email)<1 && strlen(OutputEmail)>0) strcpy(email,OutputEmail);
 
    strcpy(tmp2,tmp);
 
@@ -742,8 +722,7 @@ int main(argc,argv)
       z2=1;
       while(fgets(buf,MAXLEN,fp_usr)!=NULL){
         buf[strlen(buf)-1]='\0';
-        if(strstr(buf,"\r") != 0)
-           buf[strlen(buf)-1]='\0';
+        if(strstr(buf,"\r") != 0) buf[strlen(buf)-1]='\0';
         getword(bufy,buf,' ');
         for(z1=0; z1<=strlen(bufy); z1++) {
            userfile[z2]=bufy[z1];
@@ -782,16 +761,14 @@ int main(argc,argv)
      exit(1);
    }
    fgets(bufz,sizeof(bufz),fp_in);
-   if(!isalog) {
-      if(strncmp(bufz,"#Software: Mic",14) == 0)
-         isalog++;
-   }
+   if(!isalog && strncmp(bufz,"#Software: Mic",14) == 0) isalog++;
+
    if(strncmp(bufz,"*** SARG Log ***",16) == 0) {
       getword(val2,arqtt,'-');
       getword(val2,arqtt,'_');
       getword(val3,arqtt,'-');
       getword(val3,arqtt,'_');
-      sprintf(periodo,"%s-%s",val2,val3);
+      sprintf(period,"%s-%s",val2,val3);
       sarglog=1;
    } else lseek(fileno(fp_in), 0, 0);
 
@@ -829,15 +806,13 @@ int main(argc,argv)
       rewind(fp_in);
       recs1=0;
       recs2=0;
-      while( fgets(bufz,sizeof(bufz),fp_in) != NULL )
-         recs1++;
+      while( fgets(bufz,sizeof(bufz),fp_in) != NULL ) recs1++;
       rewind(fp_in);
 
       printf("SARG: Records in file: %d, reading: %3.2f%%\r",recs1,(float) 0);
       fflush( stdout ) ;
    }
    
-    
    while(fgets(bufz,sizeof(bufz),fp_in)!=NULL) {
 	recs2++;
 	if( bool_ShowReadStatistics && ! --OutputNonZero) {
@@ -930,6 +905,10 @@ int main(argc,argv)
 	      getword(tam,bufz,' ');
 	      getword(fun,bufz,' ');
 	      getword(url,bufz,' ');
+              while (strstr(bufz,"%20") != 0) {
+                 getword(warea,bufz,' ');
+                 strcat(url,warea);
+              }
 	      getword(user,bufz,' ');
 	      squid_log=1;
 	   }
@@ -988,6 +967,11 @@ int main(argc,argv)
            sprintf(data," %s/%s/%s:%s",dia,mes,ano,hora);
         }
 
+        if(strlen(user) > 150) {
+           totregsx++;
+           continue;
+        }
+
 	// include_users
 	if(strlen(IncludeUsers) > 0) {
            sprintf(val1,":%s:",user);
@@ -1169,12 +1153,14 @@ int main(argc,argv)
 	      strcpy(user,"everybody");
         }
 
+        if(dotinuser) {
+           str2=(char *)subs(user,"_",".");
+           strcpy(user,str2);
+           dotinuser=0;
+        }
+
         if(puser) {
            sprintf(wuser,":%s:",user);
-           if(dotinuser && strstr(wuser,"_")) {
-               str2=(char *)subs(wuser,"_",".");
-               strcpy(wuser,str2);
-            }
            if(strstr(userfile, wuser) == 0)
               continue;
         }
@@ -1215,7 +1201,7 @@ int main(argc,argv)
 #else
               if((fp_ou=fopen(tmp3,"a"))==NULL) {
 #endif
-                fprintf(stderr, "%s: (log) %s: %s - %s\n",argv[0],text[9],tmp3,strerror(errno));
+                fprintf(stderr, "%s: (zzzlog) %s: %s - %s\n",argv[0],text[9],tmp3,strerror(errno));
                 exit(1);
               }
               fputs(bufz,fp_ou);
@@ -1293,13 +1279,13 @@ int main(argc,argv)
        
               if(!totper && !sarglog){
 	         totper++;
-                 sprintf(periodo,"%s-",tbuf);
+                 sprintf(period,"%s-",tbuf);
                  sprintf(per_hour,"%s-",tbuf2);
                  if(strlen(date)>0)
-                    fixper(tbuf, periodo, cduntil);
+                    fixper(tbuf, period, cduntil);
                  if(debugz){
                     debugaz("tbuf",tbuf);
-                    debugaz("periodo",periodo);
+                    debugaz("period",period);
                  }
 	      }
            }
@@ -1377,18 +1363,18 @@ int main(argc,argv)
    }
 
    if(date[0] == '\0' && !sarglog) {
-      strcat(periodo,tbuf);
+      strcat(period,tbuf);
       strcat(per_hour,tbuf2);
    }
 
    if(debugz){
       debugaz("data",dia);
       debugaz("tbuf",tbuf);
-      debugaz("periodo",periodo);
+      debugaz("period",period);
    }
 
    if(debug){
-     sprintf(msg, "%s: %s",text[17],periodo);
+     sprintf(msg, "%s: %s",text[17],period);
      debuga(msg);
    }
 
@@ -1401,7 +1387,7 @@ int main(argc,argv)
 
    if(strcmp(ParsedOutputLog, "no") != 0 && !sarglog) {
       fclose(fp_log); 
-      strcpy(val1,periodo);
+      strcpy(val1,period);
       getword(val2,val1,'-');
       getword(val3,per_hour,'-');
       sprintf(val4,"%s/sarg-%s_%s-%s_%s.log",ParsedOutputLog,val2,val3,val1,per_hour);
@@ -1420,6 +1406,10 @@ int main(argc,argv)
    }
 
    if(strstr(ReportType,"denied") != 0) {
+      if(debug) {
+         sprintf(msg,"%s %s",text[54],tmp4);
+         debuga(msg);
+      }
       sprintf(csort,"sort -T %s -k 3,3 -k 5,5 -o '%s' '%s'",tmp,tmp5,tmp4);
       system(csort);
       unlink(tmp4);
@@ -1540,7 +1530,7 @@ void gethexclude(char *hexfile, int debug)
      strcat(excludefile," ");
    }
 
-   strcat(excludefile,"*FIM* ");
+   strcat(excludefile,"*END* ");
 
    fclose(fp_ex);
 
@@ -1584,7 +1574,7 @@ void getuexclude(char *uexfile, int debug)
      strcat(excludeuser," ");
    }
 
-   strcat(excludeuser,"*FIM* ");
+   strcat(excludeuser,"*END* ");
 
    fclose(fp_ex);
 
