@@ -1,6 +1,6 @@
 /*
- * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
- *                                                            1998, 2005
+ * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
+ *                                                            1998, 2006
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -29,7 +29,7 @@
 void gerarel()
 {
 
-   FILE *fp_in, *fp_ou;
+   FILE *fp_in;
 
    char accdia[11], acchora[9], accuser[MAXLEN], accip[MAXLEN], accurl[MAXLEN], accbytes[12], accelap[10];
    char oldaccdia[11], oldacchora[9], oldaccip[MAXLEN], wdir[MAXLEN], per1[MAXLEN];
@@ -54,9 +54,9 @@ void gerarel()
    nameantes[0]='\0';
    smartfilter=0;
 
-   sprintf(dirname, "%s%s", outdir, periodo);
-   sprintf(wdir, "%s%s", outdir, periodo);
-   strcpy(per1,periodo);
+   sprintf(dirname, "%s%s", outdir, period);
+   sprintf(wdir, "%s%s", outdir, period);
+   strcpy(per1,period);
    vrfydir(wdir, per1, addr, site, us, email);
 
    if(debugz){
@@ -65,23 +65,19 @@ void gerarel()
    }
  
    strcpy(wdirname,dirname);
-   gperiodo();
+   gperiod();
 
-   if(strlen(UserAgentLog) > 0 && email[0] == '\0') 
-      useragent();
+   if(strlen(UserAgentLog) > 0 && email[0] == '\0') useragent();
 
    olduser[0]='\0';
    strncat(tmp,"/sarg",5);
 
    dirp = opendir(tmp);
    while ((direntp = readdir( dirp )) != NULL ) {
-      if(strstr(direntp->d_name,".log") == 0)
-         continue;
-      if(strncmp(direntp->d_name,"download.log",12) == 0)
-         continue;
-      if(strncmp(direntp->d_name,"denied.log",10) == 0)
-         continue;
-      if(strncmp(direntp->d_name,"authfail.log.unsort",19) == 0)
+      if((strstr(direntp->d_name,".log") == 0) ||
+         (strncmp(direntp->d_name,"download.log",12) == 0) ||
+         (strncmp(direntp->d_name,"denied.log",10) == 0) ||
+	 (strncmp(direntp->d_name,"authfail.log.unsort",19) == 0))
          continue;
       sprintf(tmp3,"%s/%s",tmp,direntp->d_name);
       if((fp_in=fopen(tmp3,"r"))==NULL){
@@ -114,8 +110,7 @@ void gerarel()
          getword(accurl,buf,' ');
          getword(accbytes,buf,' ');
          getword(acccode,buf,' ');
-         if(strncmp(acccode,"TCP_DENIED/407",14) == 0)
-            continue;
+         if(strncmp(acccode,"TCP_DENIED/407",14) == 0) continue;
          getword(accelap,buf,' ');
          getword(accsmart,buf,' ');
          getword(accsmart,buf,'"');
@@ -225,35 +220,19 @@ void gerarel()
                   *s=tolower(*s);
             }
 
-            fputs("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\"",fp_tt);
-            fputs(" \"http://www.w3.org/TR/html4/loose.dtd\">\n",fp_tt);
-            fputs("<html>\n",fp_tt);
-            fputs("<head>\n",fp_tt);
-            sprintf(html,"  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=%s\">\n",CharSet);
-            fputs(html,fp_tt);
+	    fprintf(fp_tt, "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n<html>\n<head>\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=%s\">\n",CharSet);
             css(fp_tt);
             fputs("</head>\n",fp_tt);
-
-            sprintf(html,"<body bgcolor=%s text=%s background='%s'>\n",BgColor,TxColor,BgImage);
-            fputs(html,fp_tt);
-
-            fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_tt);
-
-            if(strlen(LogoImage) > 0) {
-               fputs("<center><table cellpadding=\"0\" cellspacing=\"0\">\n",fp_tt);
-               sprintf(html,"<tr><th class=\"logo\"><img src='%s' border=0 align=absmiddle width=%s height=%s>&nbsp;%s</th></tr>\n",LogoImage,Width,Height,LogoText);
-               fputs(html,fp_tt);
-               fputs("<tr><td height=\"5\"></td></tr>\n",fp_tt);
-               fputs("</table>\n",fp_tt);
-            }
+            fprintf(fp_tt,"<body bgcolor=%s text=%s background='%s'>\n",BgColor,TxColor,BgImage);
+	    if(strlen(LogoImage) > 0) fprintf(fp_tt, "<center><table cellpadding=\"0\" cellspacing=\"0\">\n<tr><th class=\"logo\"><img src='%s' border=0 align=absmiddle width=%s height=%s>&nbsp;%s</th></tr>\n<tr><td height=\"5\"></td></tr>\n</table>\n",LogoImage,Width,Height,LogoText);
 
             if(strcmp(IndexTree,"date") == 0)
                show_sarg(fp_tt, "../../../..");
             else
                show_sarg(fp_tt, "../..");
 
-            sprintf(html,"<tr><th class=\"title\" colspan=\"2\">%s</th></tr>\n",Title);
-            fputs(html,fp_tt);
+            fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_tt);
+            fprintf(fp_tt,"<tr><th class=\"title\" colspan=\"2\">%s</th></tr>\n",Title);
 
             strcpy(u2,user);
             if(strcmp(Ip2Name,"yes") == 0)
@@ -277,24 +256,17 @@ void gerarel()
                strcpy(name,str2);
             }
 
-            sprintf(html,"<tr><td class=\"header\" colspan=\"2\">%s:&nbsp;%s</td></tr>\n",text[89],periodo);
-            fputs(html,fp_tt);
-            sprintf(html,"<tr><td class=\"header\" colspan=\"2\">%s:&nbsp;%s</td></tr>\n",text[90],name);
-            fputs(html,fp_tt);
-            sprintf(html,"<tr><td class=\"header\" colspan=\"2\">%s:&nbsp;%s, %s</td></tr>\n",text[104],UserSortField,UserSortOrder);
-            fputs(html,fp_tt);
-            sprintf(html,"<tr><td class=\"header3\" colspan=2>%s %s</td></tr>\n",text[32],text[55]);
-            fputs(html,fp_tt);
+	    fprintf(fp_tt,"<tr><td class=\"header\" colspan=\"2\">%s:&nbsp;%s</td></tr>\n",text[89],period);
+	    fprintf(fp_tt,"<tr><td class=\"header\" colspan=\"2\">%s:&nbsp;%s</td></tr>\n",text[90],name);
+	    fprintf(fp_tt,"<tr><td class=\"header\" colspan=\"2\">%s:&nbsp;%s, %s</td></tr>\n",text[104],UserSortField,UserSortOrder);
+	    fprintf(fp_tt,"<tr><th class=\"header3\" colspan=2>%s</th></tr>\n",text[32]);
 
             fputs("</table></center>\n",fp_tt);
             fputs("<center><table cellpadding=\"0\" cellspacing=\"2\">\n",fp_tt);
             fputs("<tr><td></td><td></td></tr>",fp_tt);
             bzero(tmp4, MAXLEN);
-            bzero(tmp5, MAXLEN);
             strncpy(tmp4,text[110],4);
-            strncpy(tmp5,text[110]+5,4);
-            sprintf(html,"<tr><th class=\"data\">%s</th><th class=\"data\">%s</th><th class=\"data\">%s</th></tr>\n",text[91],tmp4,tmp5);
-            fputs(html,fp_tt);
+            fprintf(fp_tt,"<tr><th class=\"header\">%s</th><th class=\"header\">%s</th><th class=\"header\">%s</th></tr>\n",text[91],tmp4,text[110]+5);
 	 }
 
          sprintf(html,"<tr><td class=\"data\">%s</td><td class=\"data\">%s</td><td class=\"data\">%s</td></tr>\n",accurl,accdia,acchora);
@@ -302,9 +274,7 @@ void gerarel()
 	 if(strcmp(html,html_old) != 0)
             fputs(html,fp_tt);
 	 strcpy(html_old, html);
-      } else {
-         bzero(ltext110, 50);
-      } 
+      } else bzero(ltext110, 50);
 
       strcpy(wcrc,acccode);
       getword(crc2,wcrc,'/');
@@ -349,8 +319,7 @@ void gerarel()
    totalger(wdirname, debug, outdir);
 
    if(strlen(email) == 0) {
-      if(strstr(ReportType,"downloads") != 0)
-         download_report();
+      if(strstr(ReportType,"downloads") != 0) download_report();
 
       if(strlen(DansGuardianConf) > 0) {
          strcpy(wdirname,dirname);
@@ -363,39 +332,31 @@ void gerarel()
       strcpy(wdirname,dirname);
       topuser();
 
-      if(strstr(ReportType,"topsites") != 0)
-         topsites();
+      if(strstr(ReportType,"topsites") != 0) topsites();
 
-      if(strstr(ReportType,"sites_users") != 0)
-         siteuser();
+      if(strstr(ReportType,"sites_users") != 0) siteuser();
       gen_denied_report();
 
       strcpy(wdirname,dirname);
       authfail_report();
 
-      if(smartfilter)
-         smartfilter_report();
+      if(smartfilter) smartfilter_report();
 
-      if(strlen(DansGuardianConf) > 0)
-         dansguardian_report();
+      if(strlen(DansGuardianConf) > 0) dansguardian_report();
 
       squidguard_report();
 
-      if(strstr(ReportType,"users_sites") != 0)
-         htmlrel();
+      if(strstr(ReportType,"users_sites") != 0) htmlrel();
 
       make_index();
 
-      if(strncmp(SuccessfulMsg,"yes",3) == 0)
-         fprintf(stderr, "SARG: %s %s\n",text[47],dirname);
+      if(strncmp(SuccessfulMsg,"yes",3) == 0) fprintf(stderr, "SARG: %s %s\n",text[47],dirname);
     } else {
       strcpy(wdirname,dirname);
       geramail(wdirname, debug, outdir, userip, email, TempDir);
 
-      if(strcmp(email,"stdout") != 0) {
-         if(strncmp(SuccessfulMsg,"yes",3) == 0)
+      if((strcmp(email,"stdout") != 0) && (strncmp(SuccessfulMsg,"yes",3) == 0))
             fprintf(stderr, "SARG: %s %s\n",text[48],email);
-      }
    }
 
    if(indexonly) {
@@ -469,7 +430,6 @@ void gravatmp(char *oldaccuser, char *dirname, char *oldurl, long long int nacc,
 
    FILE *fp_ou;
 
-   char reg[MAXLEN];
    char wdirname[MAXLEN];
 
    if(indexonly) return;
@@ -490,8 +450,7 @@ void gravatmp(char *oldaccuser, char *dirname, char *oldurl, long long int nacc,
    my_lltoa(nelap,val3,15);
    my_lltoa(incache,val4,15);
    my_lltoa(oucache,val5,15);
-   sprintf(reg,"%s %s %s %s %s %s %s\n",val1,val2,oldurl,oldmsg,val3,val4,val5);
-   fputs(reg,fp_ou);
+   fprintf(fp_ou,"%s %s %s %s %s %s %s\n",val1,val2,oldurl,oldmsg,val3,val4,val5);
 
    fclose(fp_ou);
    ttopen=0;
@@ -512,11 +471,9 @@ void gravatmp_hora(char *dirname, char *user, char *data, char *hora, char *elap
 
    FILE *fp_ou;
 
-   char reg[MAXLEN];
    char wdirname[MAXLEN];
 
-   if(indexonly) return;
-   if(strstr(ReportType,"users_sites") == 0) return;
+   if(indexonly || (strstr(ReportType,"users_sites") == 0)) return;
 
    strcpy(wdirname,tmp);
    strcat(wdirname,"/");
@@ -528,10 +485,8 @@ void gravatmp_hora(char *dirname, char *user, char *data, char *hora, char *elap
       exit(1);
    }
 
-   if(strcmp(datetimeby,"bytes") == 0)
-      sprintf(reg,"%s %s %s\n",data,hora,bytes);
-   else sprintf(reg,"%s %s %s\n",data,hora,elap);
-   fputs(reg,fp_ou);
+   if(strcmp(datetimeby,"bytes") == 0) fprintf(fp_ou,"%s %s %s\n",data,hora,bytes);
+   else fprintf(fp_ou,"%s %s %s\n",data,hora,elap);
 
    fclose(fp_ou);
 
@@ -544,11 +499,9 @@ void gravaporuser(char *user, char *dirname, char *url, char *ip, char *data, ch
 
    FILE *fp_ou;
 
-   char reg[MAXLEN];
    char wdirname[MAXLEN];
 
-   if(indexonly) return;
-   if(strstr(ReportType,"users_sites") == 0) return;
+   if(indexonly || (strstr(ReportType,"users_sites") == 0)) return;
 
    strcpy(wdirname,tmp);
    strcat(wdirname,"/");
@@ -560,8 +513,7 @@ void gravaporuser(char *user, char *dirname, char *url, char *ip, char *data, ch
       exit(1);
    } 
 
-   sprintf(reg,"%s %s %s %s %s %s\n",ip,url,data,hora,tam,elap);
-   fputs(reg,fp_ou);
+   fprintf(fp_ou,"%s %s %s %s %s %s\n",ip,url,data,hora,tam,elap);
 
    fclose(fp_ou);
 
@@ -575,11 +527,9 @@ void gravatmpf(char *oldaccuser, char *dirname, char *oldurl, long long int nacc
 
    FILE *fp_ou;
 
-   char reg[MAXLEN];
    char wdirname[MAXLEN];
 
-   if(indexonly) return;
-   if(strstr(ReportType,"users_sites") == 0) return;
+   if(indexonly || (strstr(ReportType,"users_sites") == 0)) return;
 
    strcpy(wdirname,tmp);
    strcat(wdirname,"/");
@@ -596,8 +546,7 @@ void gravatmpf(char *oldaccuser, char *dirname, char *oldurl, long long int nacc
    my_lltoa(nelap,val3,15);
    my_lltoa(incache,val4,15);
    my_lltoa(oucache,val5,15);
-   sprintf(reg,"%s %s %s %s %s %s %s\n",val1,val2,oldurl,oldmsg,val3,val4,val5);
-   fputs(reg,fp_ou);
+   fprintf(fp_ou,"%s %s %s %s %s %s %s\n",val1,val2,oldurl,oldmsg,val3,val4,val5);
 
    fclose(fp_ou);
    ttopen=0;
@@ -618,10 +567,9 @@ void gravager(char *dirname, char *user, long long int nacc, char *url, long lon
 {
 
    FILE *fp_ou;
-   char reg[MAXLEN];
 
    strcat(dirname,"/");
-   strcat(dirname,"geral");
+   strcat(dirname,"general");
    
    if((fp_ou=fopen(dirname,"a"))==NULL){
       fprintf(stderr, "SARG: (report) %s: %s\n",text[45],dirname);
@@ -633,8 +581,7 @@ void gravager(char *dirname, char *user, long long int nacc, char *url, long lon
    my_lltoa(nelap,val3,15);
    my_lltoa(incache,val4,15);
    my_lltoa(oucache,val5,15);
-   sprintf(reg,"%s %s %s %s %s %s %s %s %s %s\n",user,val1,val2,url,ip,hora,dia,val3,val4,val5);
-   fputs(reg,fp_ou);
+   fprintf(fp_ou,"%s %s %s %s %s %s %s %s %s %s\n",user,val1,val2,url,ip,hora,dia,val3,val4,val5);
 
    fclose(fp_ou);
    return;
@@ -646,7 +593,6 @@ void grava_SmartFilter(char *dirname, char *user, char *ip, char *data, char *ho
 
    FILE *fp_ou;
 
-   char reg[MAXLEN];
    char wdirname[MAXLEN];
 
    sprintf(wdirname,"%s/smartfilter.unsort",dirname);
@@ -656,8 +602,7 @@ void grava_SmartFilter(char *dirname, char *user, char *ip, char *data, char *ho
       exit(1);
    }
 
-   sprintf(reg,"%s %s %s %s %s %s\n",user,data,hora,ip,url,smart);
-   fputs(reg,fp_ou);
+   fprintf(fp_ou,"%s %s %s %s %s %s\n",user,data,hora,ip,url,smart);
    fputs("</body>\n</html>\n",fp_tt);
 
    fclose(fp_ou);
