@@ -1,6 +1,6 @@
 /*
- * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
- *                                                            1998, 2005
+ * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
+ *                                                            1998, 2006
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -37,22 +37,24 @@ void siteuser()
    char nacc[20];
    char nbytes[20];
    char csort[255];
-   char geral[MAXLEN];
-   char geral2[MAXLEN];
+   char general[MAXLEN];
+   char general2[MAXLEN];
    char per[MAXLEN];
    char html[MAXLEN];
    char sites[MAXLEN];
    char report[MAXLEN];
-   char periodo[100];
-   char ftime[128];
+   char period[100];
    int regs=0;
    int ucount=0;
    char *users;
 
-   sprintf(geral,"%s/geral",dirname);
+   if(strcmp(Privacy,"yes") == 0)
+      return;
+
+   sprintf(general,"%s/general",dirname);
    sprintf(sites,"%s/sites",dirname);
-   sprintf(geral2,"%s/geral2",dirname);
-   sprintf(per,"%s/periodo",dirname);
+   sprintf(general2,"%s/general2",dirname);
+   sprintf(per,"%s/period",dirname);
    sprintf(report,"%s/siteuser.html",dirname);
 
    if ((fp_in = fopen(per, "r")) == 0) {
@@ -60,14 +62,14 @@ void siteuser()
       exit(1);
    }
 
-   fgets(periodo,sizeof(periodo),fp_in);
+   fgets(period,sizeof(period),fp_in);
    fclose(fp_in);
 
-   sprintf(csort,"sort -k 4,4 -k 1,1 -o '%s' '%s'",geral2,geral);
+   sprintf(csort,"sort -k 4,4 -k 1,1 -o '%s' '%s'",general2,general);
    system(csort);
 
-   if((fp_in=fopen(geral2,"r"))==NULL) {
-     fprintf(stderr, "SARG: (topsite) %s: %s\n",text[8],geral2);
+   if((fp_in=fopen(general2,"r"))==NULL) {
+     fprintf(stderr, "SARG: (topsite) %s: %s\n",text[8],general2);
      exit(1);
    }
 
@@ -76,30 +78,12 @@ void siteuser()
      exit(1);
    }
 
-   fputs("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\"",fp_ou);
-   fputs(" \"http://www.w3.org/TR/html4/loose.dtd\">\n",fp_ou);
-   fputs("<html>\n",fp_ou);
-   fputs("<head>\n",fp_ou);
-   sprintf(html,"  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=%s\">\n",CharSet);
-   fputs(html,fp_ou);
+   fprintf(fp_ou, "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n<html>\n<head>\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=%s\">\n",CharSet);
    css(fp_ou);
    fputs("</head>\n",fp_ou);
-
-   if(strlen(FontFace) > 0) {
-      sprintf(url,"<font face=%s>\n",FontFace);
-      fputs(url,fp_ou);
-   }
-
-   sprintf(url,"<body bgcolor=%s text=%s background='%s'>\n",BgColor,TxColor,BgImage);
-   fputs(url,fp_ou);
-
-   if(strlen(LogoImage) > 0) {
-      fputs("<center><table cellpadding=\"0\" cellspacing=\"0\">\n",fp_ou);
-      sprintf(url,"<tr><th class=\"logo\"><img src='%s' border=0 align=absmiddle width=%s height=%s>&nbsp;%s</th></tr>\n",LogoImage,Width,Height,LogoText);
-      fputs(url,fp_ou);
-      fputs("<tr><td height=\"5\"></td></tr>\n",fp_ou);
-      fputs("</table>\n",fp_ou);
-   }
+   if(strlen(FontFace) > 0) fprintf(fp_ou,"<font face=%s>\n",FontFace);
+   fprintf(fp_ou,"<body bgcolor=%s text=%s background='%s'>\n",BgColor,TxColor,BgImage);
+   if(strlen(LogoImage) > 0) fprintf(fp_ou, "<center><table cellpadding=\"0\" cellspacing=\"0\">\n<tr><th class=\"logo\"><img src='%s' border=0 align=absmiddle width=%s height=%s>&nbsp;%s</th></tr>\n<tr><td height=\"5\"></td></tr>\n</table>\n",LogoImage,Width,Height,LogoText);
 
    if(strcmp(IndexTree,"date") == 0)
       show_sarg(fp_ou, "../../..");
@@ -110,16 +94,14 @@ void siteuser()
    sprintf(url,"<tr><th class=\"title\">%s</th></tr>\n",Title);
    fputs(url,fp_ou);
 
-   sprintf(url,"<tr><td class=\"header3\">%s: %s</td></tr>\n",text[89],periodo);
+   sprintf(url,"<tr><td class=\"header3\">%s: %s</td></tr>\n",text[89],period);
    fputs(url,fp_ou);
-   sprintf(url,"<tr><td class=\"header3\">%s</td></tr>\n",text[85]);
+   sprintf(url,"<tr><th class=\"header3\">%s</th></tr>\n",text[85]);
    fputs(url,fp_ou);
    fputs("</table></center>\n",fp_ou);
 
    fputs("<center><table cellpadding=0 cellspacing=2>\n",fp_ou);
    fputs("<tr><td></td></tr>\n",fp_ou);
-   fputs("<tr><td></td></tr>\n",fp_ou);
-   fputs("<tr><td></td></tr>\n",fp_ou);
    sprintf(url,"<tr><th class=\"header\">%s</th><th class=\"header\">%s</th><th class=\"header\">%s</th></tr>\n",text[100],text[91],text[103]);
    fputs(url,fp_ou);
   
@@ -207,7 +189,7 @@ void siteuser()
    sprintf(html,"<tr><td class=\"data\">%d</td><td class=\"data2\"><a href=\"http://%s\">%s</td><td class=\"data2\">%s</td></tr>\n",regs,ourl,ourl,users);
    fputs(html,fp_ou);
 
-   unlink(geral2);
+   unlink(general2);
 
    fputs("</table></center>\n",fp_ou);
 
