@@ -1,6 +1,6 @@
 /*
- * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
- *                                                            1998, 2005
+ * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
+ *                                                            1998, 2006
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -36,15 +36,14 @@ int topuser()
    float perc2=0.00;
    float inperc=0.00, ouperc=0.00;
    int posicao=0;
-   char olduser[MAXLEN], csort[MAXLEN], periodo[MAXLEN], arqper[MAXLEN];
+   char olduser[MAXLEN], csort[MAXLEN], period[MAXLEN], arqper[MAXLEN];
    char wger[MAXLEN], top1[MAXLEN], top2[MAXLEN], top3[MAXLEN];
    char user[MAXLEN], nacc[20], nbytes[20], preg[MAXLEN], tusr[MAXLEN];
-   char ip[MAXLEN], hora[9], data[11], elap[15], incac[15], oucac[15], html[MAXLEN];
+   char ip[MAXLEN], time[30], date[30], elap[30], incac[30], oucac[30];
    char ipantes[MAXLEN], nameantes[MAXLEN];
    char sfield[10]="2,2";
    char order[255]="-r";
    char wheader[512]="";
-   char ftime[128];
    int  totuser=0;
    int  topcount=0;
    char *s;
@@ -57,7 +56,7 @@ int topuser()
    strcpy(top2,dirname);
    strcpy(top3,dirname);
    strcpy(tusr,dirname);
-   strcat(wger,"/geral");
+   strcat(wger,"/general");
    strcat(top1,"/top");
    strcat(top2,"/top.tmp");
    strcat(tusr,"/users");
@@ -73,16 +72,7 @@ int topuser()
     exit(1);
    }
 
-   fscanf(fp_in,"%s",user);
-   fscanf(fp_in,"%s",nacc);
-   fscanf(fp_in,"%s",nbytes);
-   fscanf(fp_in,"%s",url);
-   fscanf(fp_in,"%s",ip);
-   fscanf(fp_in,"%s",hora);
-   fscanf(fp_in,"%s",data);
-   fscanf(fp_in,"%s",elap);
-   fscanf(fp_in,"%s",incac);
-   fscanf(fp_in,"%s",oucac);
+   fscanf(fp_in,"%s%s%s%s%s%s%s%s%s%s",user,nacc,nbytes,url,ip,time,date,elap,incac,oucac);
 
    strcpy(olduser,user);
    totuser=1;
@@ -119,16 +109,7 @@ int topuser()
       tnincache+=my_atoll(incac);
       tnoucache+=my_atoll(oucac);
 
-      fscanf(fp_in,"%s",user);
-      fscanf(fp_in,"%s",nacc);
-      fscanf(fp_in,"%s",nbytes);
-      fscanf(fp_in,"%s",url);
-      fscanf(fp_in,"%s",ip);
-      fscanf(fp_in,"%s",hora);
-      fscanf(fp_in,"%s",data);
-      fscanf(fp_in,"%s",elap);
-      fscanf(fp_in,"%s",incac);
-      fscanf(fp_in,"%s",oucac);
+      fscanf(fp_in,"%s%s%s%s%s%s%s%s%s%s",user,nacc,nbytes,url,ip,time,date,elap,incac,oucac);
 
       if(strcmp(user,"TOTAL") == 0)
          continue;
@@ -199,107 +180,55 @@ int topuser()
  */
 
    strcpy(arqper,dirname);
-   strcat(arqper,"/periodo");
+   strcat(arqper,"/period");
 
    if ((fp_in = fopen(arqper, "r")) == 0) {
       fprintf(stderr, "SARG: (topuser) %s: %s\n",text[45],arqper);
       exit(1);
    }
 
-   fgets(periodo,sizeof(periodo),fp_in);
+   fgets(period,sizeof(period),fp_in);
    fclose(fp_in);
 
-   fputs("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\"",fp_top3);
-   fputs(" \"http://www.w3.org/TR/html4/loose.dtd\">\n",fp_top3);
-   fputs("<html>\n",fp_top3);
-   fputs("<head>\n",fp_top3);
-   sprintf(html,"  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=%s\">\n",CharSet);
-   fputs(html,fp_top3);
+   fprintf(fp_top3, "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n<html>\n<head>\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=%s\">\n",CharSet);
    fputs("</head>\n",fp_top3);
-
    css(fp_top3);
-
-   sprintf(preg,"<body class=\"body\">");
-   fputs(preg,fp_top3);
-
-   if(strlen(LogoImage) > 0) {
-      fputs("<center><table cellpadding=\"0\" cellspacing=\"0\">\n",fp_top3);
-      sprintf(preg,"<tr><th class=\"logo\"><img src='%s' border=0 align=absmiddle width=%s height=%s>&nbsp;%s</th></tr>\n",LogoImage,Width,Height,LogoText);
-      fputs(preg,fp_top3);
-      fputs("<tr><td height=\"5\"></td></tr>\n",fp_top3);
-      fputs("</table>\n",fp_top3);
-   }
+   fprintf(fp_top3,"<body class=\"body\">");
+   if(strlen(LogoImage) > 0) fprintf(fp_top3, "<center><table cellpadding=\"0\" cellspacing=\"0\">\n<tr><th class=\"logo\"><img src='%s' border=0 align=absmiddle width=%s height=%s>&nbsp;%s</th></tr>\n<tr><td height=\"5\"></td></tr>\n</table>\n",LogoImage,Width,Height,LogoText);
 
    if(strcmp(IndexTree,"date") == 0)
       show_sarg(fp_top3, "../../..");
    else
       show_sarg(fp_top3, "..");
    fputs("<center><table cellpadding=\"0\" cellspacing=\"0\">\n",fp_top3);
-   sprintf(preg,"<tr><th align=\"center\" class=\"title\">%s</th></tr>\n",Title);
-   fputs(preg,fp_top3);
+   fprintf(fp_top3,"<tr><th align=\"center\" class=\"title\">%s</th></tr>\n",Title);
 
-   sprintf(preg,"<tr><td class=\"header3\">%s: %s</td></tr>\n",text[89],periodo);
-   fputs(preg,fp_top3);
+   fprintf(fp_top3,"<tr><td class=\"header3\">%s: %s</td></tr>\n",text[89],period);
    strcat(wheader,(char *)text[104]);
    strcat(wheader,": ");
    strcat(wheader,TopuserSortField);
    strcat(wheader,", ");
    strcat(wheader,TopuserSortOrder);
-   sprintf(preg,"<tr><td class=\"header3\">%s</td></tr>\n",wheader);
-   fputs(preg,fp_top3);
-   sprintf(preg,"<tr><td class=\"header3\">Topuser %s</td></tr>\n",text[55]);
-   fputs(preg,fp_top3);
+   fprintf(fp_top3,"<tr><td class=\"header3\">%s</td></tr>\n",wheader);
+   fprintf(fp_top3,"<tr><th class=\"header3\">%s</th></tr>\n",text[137]);
 
    fputs("</table></center>\n",fp_top3);
    fputs("<center><table cellpadding=\"1\" cellspacing=\"2\">\n",fp_top3);
    fputs("<tr><td><br></td><td></td></tr>\n",fp_top3);
 
-   if(strstr(ReportType,"topsites") != 0) {
-      sprintf(preg,"<tr><td class=\"link\" colspan=11><a href=\"topsites.html\"><font class=\"link\">%s</font></a><font class=\"text\"> %s</font></td></tr>\n",text[119],text[55]);
-      fputs(preg,fp_top3);
-   }
-
-   if(strstr(ReportType,"sites_users") != 0) {
-      sprintf(preg,"<tr><td class=\"link\" colspan=11><a href=\"siteuser.html\"><font class=\"link\">%s</font></a><font class=\"text\"> %s</font></td></tr>\n",text[85],text[55]);
-      fputs(preg,fp_top3);
-   }
-
-   if(dansguardian_count) {
-     sprintf(preg,"<tr><td class=\"link\" colspan=11><a href=\"dansguardian.html\"><font class=\"link\">%s</font></a><font class=\"text\"> %s</font></td></tr>\n",text[128],text[55]);
-     fputs(preg,fp_top3);
-   }
-
-   if(squidguard_count) {
-     sprintf(preg,"<tr><td class=\"link\" colspan=11><a href=\"squidguard.html\"><font class=\"link\">%s</font></a><font class=\"text\"> %s</font></td></tr>\n",text[122],text[55]);
-     fputs(preg,fp_top3);
-   }
-
-   if (strstr(ReportType,"downloads") != 0 && download_count) {
-      sprintf(preg,"<tr><td class=\"link\" colspan=11><a href=\"download.html\"><font class=\"link\">%s</font></a><font class=\"text\"> %s</font></td></tr>\n",text[125],text[55]);
-      fputs(preg,fp_top3);
-   }
-
-   if (strstr(ReportType,"denied") != 0 && denied_count) {
-      sprintf(preg,"<tr><td class=\"link\" colspan=11><a href=\"denied.html\"><font class=\"link\">%s</font></a><font class=\"text\"> %s</font></td></tr>\n",text[118],text[55]);
-      fputs(preg,fp_top3);
-   }
-
-   if (strstr(ReportType,"auth_failures") != 0 && authfail_count) {
-      sprintf(preg,"<tr><td class=\"link\" colspan=11><a href=\"authfail.html\"><font class=\"link\">%s</font></a><font class=\"text\"> %s</font></td></tr>\n",text[117],text[55]);
-      fputs(preg,fp_top3);
-   }
-
-   if(smartfilter) {
-      sprintf(preg,"<tr><td class=\"link\" colspan=11><a href=\"smartfilter.html\"><font class=\"link\">%s</font></a><font class=\"text\"> %s</font></td></tr>\n",text[116],text[55]);
-      fputs(preg,fp_top3);
-   }
-   strcpy(preg,"<tr><td></td></tr>\n");
-   fputs(preg,fp_top3);
+   if(strstr(ReportType,"topsites") != 0 && strcmp(Privacy,"yes") != 0) fprintf(fp_top3,"<tr><td class=\"link\" colspan=11><a href=\"topsites.html\"><font class=\"link\">%s</font></a><font class=\"text\"></font></td></tr>\n",text[119]);
+   if(strstr(ReportType,"sites_users") != 0 && strcmp(Privacy,"yes") != 0) fprintf(fp_top3,"<tr><td class=\"link\" colspan=11><a href=\"siteuser.html\"><font class=\"link\">%s</font></a><font class=\"text\"></font></td></tr>\n",text[85]);
+   if(dansguardian_count) fprintf(fp_top3,"<tr><td class=\"link\" colspan=11><a href=\"dansguardian.html\"><font class=\"link\">%s</font></a><font class=\"text\"></font></td></tr>\n",text[128]);
+   if(squidguard_count) fprintf(fp_top3,"<tr><td class=\"link\" colspan=11><a href=\"squidguard.html\"><font class=\"link\">%s</font></a><font class=\"text\"></font></td></tr>\n",text[122]);
+   if (strstr(ReportType,"downloads") != 0 && download_count && strcmp(Privacy,"yes") != 0) fprintf(fp_top3,"<tr><td class=\"link\" colspan=11><a href=\"download.html\"><font class=\"link\">%s</font></a><font class=\"text\"></font></td></tr>\n",text[125]);
+   if (strstr(ReportType,"denied") != 0 && denied_count && strcmp(Privacy,"yes") != 0) fprintf(fp_top3,"<tr><td class=\"link\" colspan=11><a href=\"denied.html\"><font class=\"link\">%s</font></a><font class=\"text\"></font></td></tr>\n",text[118]);
+   if (strstr(ReportType,"auth_failures") != 0 && authfail_count && strcmp(Privacy,"yes") != 0) fprintf(fp_top3,"<tr><td class=\"link\" colspan=11><a href=\"authfail.html\"><font class=\"link\">%s</font></a><font class=\"text\"></font></td></tr>\n",text[117]);
+   if(smartfilter) fprintf(fp_top3,"<tr><td class=\"link\" colspan=11><a href=\"smartfilter.html\"><font class=\"link\">%s</font></a><font class=\"text\"></font></td></tr>\n",text[116]);
+   fputs("<tr><td></td></tr>\n",fp_top3);
 
    if (strstr(ReportType,"topuser") == 0) {
       fputs("</body>\n</html>\n",fp_top3);
-      if (fp_top3)
-         fclose (fp_top3);
+      if (fp_top3) fclose (fp_top3);
       return;
    }
    strcpy(val1,text[100]);
@@ -364,16 +293,9 @@ int topuser()
       bzero(hbc8, 30);
    }
 
-     sprintf(preg,"<tr><th %s>%s</th><th %s></th><th %s>%s</th><th %s>%s</th><th %s>%s</th><th %s>%s</th><th %s %s>%s%s</th><th %s>%s</th><th %s>%s</th><th %s>%s</th></tr>\n",hbc1,val1,hbc1,hbc2,val2,hbc3,val3,hbc4,val4,hbc9,val11,hbc5,val9,val5,val10,hbc6,val6,hbc7,val7,hbc8,val8);
+   fprintf(fp_top3,"<tr><th %s>%s</th><th %s></th><th %s>%s</th><th %s>%s</th><th %s>%s</th><th %s>%s</th><th %s %s>%s%s</th><th %s>%s</th><th %s>%s</th><th %s>%s</th></tr>\n",hbc1,val1,hbc1,hbc2,val2,hbc3,val3,hbc4,val4,hbc9,val11,hbc5,val9,val5,val10,hbc6,val6,hbc7,val7,hbc8,val8);
 
-   fputs(preg,fp_top3);
-
-   fscanf(fp_top1,"%s",user);
-   fscanf(fp_top1,"%s",nbytes);
-   fscanf(fp_top1,"%s",nacc);
-   fscanf(fp_top1,"%s",elap);
-   fscanf(fp_top1,"%s",incac);
-   fscanf(fp_top1,"%s",oucac);
+   fscanf(fp_top1,"%s%s%s%s%s%s",user,nbytes,nacc,elap,incac,oucac);
 
    while(!feof(fp_top1)) {
       if(atoi(TopUsersNum) > 0 && topcount >= atoi(TopUsersNum)) goto final;
@@ -459,12 +381,10 @@ int topuser()
          } else strcpy(name,user2);
       } else strcpy(name,user2);
 
-      if(strcmp(Ip2Name,"yes") == 0) {
-         if((str=(char *) strstr(name, ".")) != (char *) NULL) {
-            if((str=(char *) strstr(str+1, ".")) != (char *) NULL)
+      if((strcmp(Ip2Name,"yes") == 0) && 
+        ((str=(char *) strstr(name, ".")) != (char *) NULL) && 
+	((str=(char *) strstr(str+1, ".")) != (char *) NULL))
                ip2name(name);
-         }
-      }
 
       twork=my_atoll(nacc);
       my_lltoa(twork,nacc,0);
@@ -474,9 +394,9 @@ int topuser()
 
       sprintf(val1,"%d",posicao);
 #ifdef HAVE_GD
-      sprintf(val2,"%s<img src=\"%s/graph.png\" border=\"0\" title=\"%s %s\"></a>&nbsp;%s<img src=\"%s/datetime.png\" border=\"0\" title=\"%s %s\">\n",href3,ImageFile,text[126],text[55],href2,ImageFile,ltext110,text[55]);
+      sprintf(val2,"%s<img src=\"%s/graph.png\" border=\"0\" title=\"%s\"></a>&nbsp;%s<img src=\"%s/datetime.png\" border=\"0\" title=\"%s %s\">\n",href3,ImageFile,text[126],href2,ImageFile,ltext110,text[55]);
 #else
-      sprintf(val2,"%s<img src=\"%s/datetime.png\" border=\"0\" title=\"%s %s\">\n",href2,ImageFile,ltext110,text[55]);
+      sprintf(val2,"%s<img src=\"%s/datetime.png\" border=\"0\" title=\"%s\">\n",href2,ImageFile,ltext110);
 #endif
 
       sprintf(val3,"%3.2f%%",perc);
@@ -516,6 +436,7 @@ int topuser()
          bzero(val3, 255);
          bzero(hbc5, 30);
       }
+
       if(strstr(TopUserFields,"IN-CACHE-OUT") == 0) {
          bzero(val4, 255);
          bzero(hbc6, 30);
@@ -614,17 +535,11 @@ int topuser()
 
       topcount++;
 
-      fscanf(fp_top1,"%s",user);
-      fscanf(fp_top1,"%s",nbytes);
-      fscanf(fp_top1,"%s",nacc);
-      fscanf(fp_top1,"%s",elap);
-      fscanf(fp_top1,"%s",incac);
-      fscanf(fp_top1,"%s",oucac);
+      fscanf(fp_top1,"%s%s%s%s%s%s",user,nbytes,nacc,elap,incac,oucac);
    }
 
-   if(ttnbytes) {
-      tnbytes=ttnbytes / totuser;
-   } else tnbytes=0;
+   if(ttnbytes) tnbytes=ttnbytes / totuser;
+   else tnbytes=0;
 
    twork=ttnacc/totuser;
    twork2=ttnelap/totuser;
@@ -655,13 +570,8 @@ int topuser()
       bzero(hbc6, 30);
    }
 
-   if((strstr(ReportType,"date_time") != 0 && strstr(TopUserFields,"AVERAGE") != 0)) {
-      sprintf(preg,"<tr><td></td><th></th><th %s>%s</th><th %s>%s</th><th %s>%15s</th><td></td><td></td><td></td><th %s>%s</th><th %s>%s</th></tr>\n",hbc10,text[96],hbc1,wwork1,hbc2,wwork2,hbc3,buildtime(ttnelap/totuser),hbc4,wwork3);
-      fputs(preg,fp_top3);
-    } else if(strstr(TopUserFields,"AVERAGE") != 0) {
-         sprintf(preg,"<tr><td></td><th></th><td></td><th %s>%s</th><th %s>%s</th><th %s>%15s</th><td></td><td></td><td></td><th %s>%s</th><th %s>%s</th></tr>\n",hbc10,text[96],hbc1,wwork1,hbc2,wwork2,hbc3,buildtime(ttnelap/totuser),hbc4,wwork3);
-         fputs(preg,fp_top3);
-   }
+   if((strstr(ReportType,"date_time") != 0 && strstr(TopUserFields,"AVERAGE") != 0)) fprintf(fp_top3,"<tr><td></td><th></th><th %s>%s</th><th %s>%s</th><th %s>%15s</th><td></td><td></td><td></td><th %s>%s</th><th %s>%s</th></tr>\n",hbc10,text[96],hbc1,wwork1,hbc2,wwork2,hbc3,buildtime(ttnelap/totuser),hbc4,wwork3);
+   else if(strstr(TopUserFields,"AVERAGE") != 0) fprintf(fp_top3,"<tr><td></td><th></th><td></td><th %s>%s</th><th %s>%s</th><th %s>%15s</th><td></td><td></td><td></td><th %s>%s</th><th %s>%s</th></tr>\n",hbc10,text[96],hbc1,wwork1,hbc2,wwork2,hbc3,buildtime(ttnelap/totuser),hbc4,wwork3);
 
    if(strlen(UserAgentLog) > 0) {
       fputs("<tr><td></td></tr>\n",fp_top3);
@@ -669,8 +579,7 @@ int topuser()
       fputs("<td align=\"left\" colspan=8><font size=-1><a href='useragent.html'>Useragent</a> Report</td>\n",fp_top3);
    }
 
-   strcpy(preg,"</table></center>");
-   fputs(preg,fp_top3);
+   fputs("</table></center>",fp_top3);
 
    show_info(fp_top3);
 
@@ -683,8 +592,7 @@ final:
       exit(1);
    }
 
-   sprintf(preg,"%d\n",totuser);
-   fputs(preg,fp_ou);
+   fprintf(fp_ou,"%d\n",totuser);
 
    fputs("</body>\n</html>\n",fp_top3);
    fclose(fp_top3);
