@@ -1,6 +1,6 @@
 /*
- * AUTHOR: Pedro Lineu Orso                      orso@penguintech.com.br
- *                                                            1998, 2005
+ * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
+ *                                                            1998, 2006
  * SARG Squid Analysis Report Generator      http://sarg.sourceforge.net
  *
  * SARG donations:
@@ -31,43 +31,61 @@
 static char mtab1[12][4]={"Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"};
 static char mtab2[12][3]={"01","02","03","04","05","06","07","08","09","10","11","12"};
 
+/*void fgetword(char *word, char *line, int stop)
+{
+    //VARIANT N1
+    int x;
+    
+    for (x=0; line[x] && (line[x] != stop); x++) word[x] = line[x];
+    word[x] = '\0';
+
+    //VARIANT N2
+    char *tchar;
+    int difflen;
+    
+    tchar = strchr(line, stop);
+    if (tchar == NULL) strcpy(word, line);
+    else
+    {
+	difflen = tchar - line;
+	strncpy(word, line, difflen);
+	word[difflen] = '\0';
+    }
+}*/
+
 void getword(char *word, char *line, int stop)
 {
-  int x = 0,y;
-  int loop=0;
+  int x = 0, y = 0;
   int limit=10000;
   char wline[MAXLEN];
 
-  strcpy(wline,line);
+  //strcpy(wline,line);
 
   if(strlen(line) < 3) {
      word[0]='\0';
      return;
   }
 
-  for(x=0;((line[x]) && (line[x] != stop ));x++) {
-     loop++;
-     if(loop>=limit) {
-        printf("SARG: getword loop detected.\n");
-        printf("SARG: Record=\"%s\"\n",wline);
-        printf("SARG: searching for \'x%x\'\n",stop);
-        printf("SARG: Maybe you have a broken record or garbage in your access.log file.\n");
-        word[0]='\0';
-        exit(1);
-     }
-     word[x] = line[x];
+  for(x=0; line[x] && (line[x] != stop ) && x<limit; x++) word[x] = line[x];
+  if(x == limit) {
+    printf("SARG: getword loop detected.\n");
+    //printf("SARG: Record=\"%s\"\n",wline);
+    printf("SARG: searching for \'x%x\'\n",stop);
+    printf("SARG: Maybe you have a broken record or garbage in your access.log file.\n");
+    //word[0]='\0';
+    exit(1);
   }
 
   word[x] = '\0';
-  if(line[x]) ++x;
-    y=0;
+  
+  if (line[x]) ++x;
 
   while((line[y++] = line[x++]));
 }
 
 char *  getword2(char *word, char *line, int stop)
 {
-  int x = 0 , y;
+  int x = 0;
   int limit=MAXLEN;
 
   if(strlen(line) < 3) {
@@ -76,9 +94,7 @@ char *  getword2(char *word, char *line, int stop)
   }
 
   // printf( "IN Buffer <%s>\n" , line ) ;
-  for(x=0;((line[x]) && (line[x] != stop && limit ));x++ , limit-- ) {
-     word[x] = line[x];
-  }
+  for(x=0;((line[x]) && (line[x] != stop && limit ));x++ , limit-- ) word[x] = line[x];
   if(  ! limit) {
         printf("SARG: getword2 loop detected.\n");
         printf("SARG: Buffer=\"%s\"\n",line);
@@ -95,14 +111,11 @@ char *  getword2(char *word, char *line, int stop)
 
 void getword3(char *word, char *line, int stop)
 {
-  int x = 0,y;
-  int loop=0;
+  int x = 0, y = 0;
 
-  for(x=0;((line[x]) && (line[x] != stop ));x++)
-     word[x] = line[x];
+  for(x=0;(line[x] && (line[x] != stop ));x++) word[x] = line[x];
   word[x] = '\0';
   if(line[x]) ++x;
-    y=0;
   while((line[y++] = line[x++]));
 }
 
@@ -322,7 +335,7 @@ void name_month(char *month)
 }
 
 
-void fixper(char *tbuf, char *periodo, char *duntil)
+void fixper(char *tbuf, char *period, char *duntil)
 {
 
    char warea[50];
@@ -348,7 +361,7 @@ void fixper(char *tbuf, char *periodo, char *duntil)
    if(strcmp(df,"u") == 0)
       sprintf(warea,"%s%s%s",ano,mes,dia);
 
-   strcat(periodo,warea);
+   strcat(period,warea);
 }
 
 
@@ -403,7 +416,6 @@ char *fixnum(long long int value, int n)
    char *pbuf;
    char ret[MAXIMO * 2];
    char *pret;
-   float perc=0;
    register int i, j, k;
    static char abbrev[30];
       
@@ -582,7 +594,7 @@ void obttotal(char *dirname, char *name, char *tbytes, char *tuser, char *media)
    long long int med=0;
    long long int wtuser=0;
 
-   sprintf(wdir,"%s%s/geral",dirname,name);
+   sprintf(wdir,"%s%s/general",dirname,name);
 
    if ((fp_in = fopen(wdir, "r")) == 0) {
       tbytes=0;
@@ -615,8 +627,8 @@ void obttotal(char *dirname, char *name, char *tbytes, char *tuser, char *media)
 }
 
 
-//void gperiodo(char *dirname, const char *periodo)
-void gperiodo()
+//void gperiod(char *dirname, const char *period)
+void gperiod()
 {
  
    FILE *fp_ou;
@@ -625,14 +637,14 @@ void gperiodo()
 
    strcpy(wdirname,dirname);
    strcat(wdirname,"/");
-   strcat(wdirname,"periodo");
+   strcat(wdirname,"period");
 
    if((fp_ou=fopen(wdirname,"w"))==NULL){
       fprintf(stderr, "SARG: (report) %s: %s\n",text[45],wdirname);
       exit(1);
    }
  
-   fputs(periodo,fp_ou);
+   fputs(period,fp_ou);
    fclose(fp_ou);
 
    if(debug)
@@ -650,7 +662,6 @@ void vrfydir(char *dir, char *per1, char *addr, char *site, char *us, char *form
    char wdir[MAXLEN];
    char per2[MAXLEN];
    char dirname2[MAXLEN];
-   char buffer[1024];
    char images[512];
    DIR *dirp;
    struct dirent *direntp;
@@ -663,19 +674,19 @@ void vrfydir(char *dir, char *per1, char *addr, char *site, char *us, char *form
       bzero(m1,4);
       bzero(m2,4);
       if(strncmp(df,"u",1) == 0) {
-         strncpy(y1,periodo,4);
-         strncpy(y2,periodo+10,4);
-         strncpy(m1,periodo+4,3);
-         strncpy(m2,periodo+14,3);
-         strncpy(d1,periodo+7,2);
-         strncpy(d2,periodo+17,2);
+         strncpy(y1,period,4);
+         strncpy(y2,period+10,4);
+         strncpy(m1,period+4,3);
+         strncpy(m2,period+14,3);
+         strncpy(d1,period+7,2);
+         strncpy(d2,period+17,2);
       } else if(strncmp(df,"e",1) == 0) {
-         strncpy(d1,periodo+0,2);
-         strncpy(d2,periodo+10,2);
-         strncpy(m1,periodo+2,3);
-         strncpy(m2,periodo+12,3);
-         strncpy(y1,periodo+5,4);
-         strncpy(y2,periodo+15,4);
+         strncpy(d1,period+0,2);
+         strncpy(d2,period+10,2);
+         strncpy(m1,period+2,3);
+         strncpy(m2,period+12,3);
+         strncpy(y1,period+5,4);
+         strncpy(y2,period+15,4);
       }
       conv_month(m1);
       conv_month(m2);
@@ -989,10 +1000,10 @@ void removetmp(char *outdir)
       return;
    } else {
       if(debug) {
-         sprintf(msg,"%s: geral, periodo",text[82]);
+         sprintf(msg,"%s: general, period",text[82]);
          debuga(msg);
       }
-      sprintf(warea,"%s/geral",outdir);
+      sprintf(warea,"%s/general",outdir);
       if((fp_in=fopen(warea,"r"))==NULL){
          fprintf(stderr, "SARG: (removetmp) %s: %s\n",text[45],warea);
          exit(1);
@@ -1008,7 +1019,7 @@ void removetmp(char *outdir)
       }
       fputs(buf,fp_in);
       fclose(fp_in);
-      sprintf(warea,"%s/periodo",outdir);
+      sprintf(warea,"%s/period",outdir);
       unlink(warea);
    }
   
@@ -1155,24 +1166,14 @@ int getnumlist( char *buf, numlist *list, const int len, const int maxvalue )
 
 void show_info(FILE *fp_ou)
 {
-
-   if(strcmp(ShowSargInfo,"yes") == 0) {
-      zdate(ftime, DateFormat);
-      sprintf(html,"<center><table><tr><td><br><br></td><td class=\"info\">%s <a href='%s'><font class=\"info\">%s-%s</font></a> %s %s</td></tr></table></center>\n",text[108],URL,PGM,VERSION,text[109],ftime);
-      fputs(html,fp_ou);
-   }
+  if(strcmp(ShowSargInfo,"yes") != 0) return;
+  zdate(ftime, DateFormat);
+  fprintf(fp_ou,"<center><table><tr><td><br><br></td><td class=\"info\">%s <a href='%s'><font class=\"info\">%s-%s</font></a> %s %s</td></tr></table></center>\n",text[108],URL,PGM,VERSION,text[109],ftime);
 }
 
 void show_sarg(FILE *fp_ou, char *ind)
 {
-   if(strcmp(ShowSargLogo,"yes") == 0) {
-      fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_ou);
-      sprintf(html,"<tr><th class=\"logo\"><a href=\"http://sarg.sourceforge.net\"><img src=\"%s/images/sarg.png\" border=\"0\" align=\"absmiddle\" title=\"SARG, Squid Analysis Report Generator. Logo by Osamu Matsuzaki\"></a>&nbsp;<font class=\"logo\">Squid Analysis Report Generator</font></th></tr>\n",ind,Title);
-      fputs(html,fp_ou);
-      sprintf(html,"<tr><th class=\"title\">&nbsp</th></tr>\n",Title);
-      fputs(html,fp_ou);
-      fputs("<table>\n",fp_ou);
-   }
+   if(strcmp(ShowSargLogo,"yes") == 0) fprintf(fp_ou,"<center><table cellpadding=0 cellspacing=0>\n<tr><th class=\"logo\"><a href=\"http://sarg.sourceforge.net\"><img src=\"%s/images/sarg.png\" border=\"0\" align=\"absmiddle\" title=\"SARG, Squid Analysis Report Generator. Logo by Osamu Matsuzaki\"></a>&nbsp;<font class=\"logo\">Squid Analysis Report Generator</font></th></tr>\n<tr><th class=\"title\">&nbsp</th></tr>\n<table>\n",ind);
 }
 
 get_size(char *path, char *file)
@@ -1192,41 +1193,12 @@ get_size(char *path, char *file)
 
 void write_html_header(FILE *fp_ou, char * ind)
 {
-   fputs("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\"",fp_ou);
-   fputs(" \"http://www.w3.org/TR/html4/loose.dtd\">\n",fp_ou);
-   fputs("<html>\n",fp_ou);
-   fputs("<head>\n",fp_ou);
-   sprintf(html,"  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=%s\">\n",CharSet);
-   fputs(html,fp_ou);
-   fputs("</head>\n",fp_ou);
+   fprintf(fp_ou, "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n<html>\n<head>\n  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=%s\">\n</head>\n",CharSet);
    css(fp_ou);
-   sprintf(buf,"<body style=\"font-family:%s;font-size:%s;background-color:%s;background-image:url(%s)\">\n",FontFace,TitleFontSize,BgColor,BgImage);
-   fputs(buf,fp_ou);
-   sprintf(buf,"<center><table cellpadding=\"0\" cellspacing=\"0\">\n");
-   fputs(buf,fp_ou);
-   if(strlen(LogoImage) > 0) {
-      fputs("<center><table cellpadding=\"0\" cellspacing=\"0\">\n",fp_ou);
-      sprintf(html,"<tr><th class=\"logo\"><img src='%s' border=0 align=absmiddle width=%s height=%s>&nbsp;%s</th></tr>\n",LogoImage,Width,Height,LogoText);
-      fputs(html,fp_ou);
-      fputs("<tr><td height=\"5\"></td></tr>\n",fp_ou);
-      fputs("</table>\n",fp_ou);
-   }
+   fprintf(fp_ou,"<body style=\"font-family:%s;font-size:%s;background-color:%s;background-image:url(%s)\">\n",FontFace,TitleFontSize,BgColor,BgImage);
+   if(strlen(LogoImage) > 0) fprintf(fp_ou, "<center><table cellpadding=\"0\" cellspacing=\"0\">\n<tr><th class=\"logo\"><img src='%s' border=0 align=absmiddle width=%s height=%s>&nbsp;%s</th></tr>\n<tr><td height=\"5\"></td></tr>\n</table>\n",LogoImage,Width,Height,LogoText);
    show_sarg(fp_ou, ind);
-   sprintf(html,"<tr><th class=\"title\">%s</th></tr>\n",Title);
-   fputs(html,fp_ou);
-   fputs("</table></center>\n",fp_ou);
-   fputs("<center><table cellpadding=\"1\" cellspacing=\"2\">\n",fp_ou);
-   fputs("<tr><td></td><td></td></tr>\n",fp_ou);
-
-}
-
-
-void write_html_trailer(FILE *fp_ou)
-{
-   fputs("</table></center>\n",fp_ou);
-   zdate(ftime, DateFormat);
-   show_info(fp_ou);
-   fputs("</body>\n</html>\n",fp_ou);
+   fprintf(fp_ou,"<center><table cellpadding=\"0\" cellspacing=\"0\">\n<tr><th class=\"title\">%s</th></tr>\n</table></center>\n<center><table cellpadding=\"1\" cellspacing=\"2\">\n<tr><td></td><td></td></tr>\n",Title);
 }
 
 
@@ -1253,6 +1225,15 @@ char url_module(char *url, char *w2)
    return;
 }
 
+
+void write_html_trailer(FILE *fp_ou)
+{
+   fputs("</table></center>\n",fp_ou);
+   zdate(ftime, DateFormat);
+   show_info(fp_ou);
+   fputs("</body>\n</html>\n",fp_ou);
+}
+
 void version()
 {
    printf("SARG Version: %s\n",VERSION);
